
// ========================================================

/**********************************************************
**Name:     SPICmd8bit
**Function: SPI Write one byte
**Input:    WrPara
**Output:   none
**note:     use for burst mode
**********************************************************/
void SPICmd8bit(unsigned char WrPara)
{
  unsigned char bitcnt;  
  SCK=0;
  NSS=0;
  //P11=0;
  SCK=0;
  _nop_();
  for(bitcnt=8; bitcnt!=0; bitcnt--)
  {
    SCK=0;
	_nop_();
	_nop_();
	   _nop_();
	  _nop_();
    if(WrPara&0x80)
      MOSI=1;
    else
      MOSI=0;
    _nop_();
	_nop_();
	_nop_();
     _nop_();
	  _nop_();
	SCK=1;
	_nop_();
	_nop_();
	_nop_();
    WrPara <<= 1;
  }
  SCK=0;
  MOSI=1;
}

/**********************************************************
**Name:     SPIRead8bit
**Function: SPI Read one byte
**Input:    None
**Output:   result byte
**Note:     use for burst mode
**********************************************************/
unsigned char SPIRead8bit(void)
{
 unsigned char RdPara = 0;
 unsigned char bitcnt;
 
  NSS=0;
  _nop_();
  MOSI=1;                                                 //Read one byte data from FIFO, MOSI hold to High
  for(bitcnt=8; bitcnt!=0; bitcnt--)
  {
    _nop_();
    SCK=0;
	_nop_();
	_nop_();
    RdPara <<= 1;
    SCK=1;
	_nop_();
	_nop_();
    if(MISO)
      RdPara |= 0x01;
    else
      RdPara |= 0x00;
  }
  SCK=0;
  return(RdPara);
}

/**********************************************************
**Name:     SPIRead
**Function: SPI Read CMD
**Input:    adr -> address for read
**Output:   None
**********************************************************/
unsigned char SPIRead(unsigned char adr)
{
  unsigned char tmp; 
  SPICmd8bit(adr);                                         //Send address first
  tmp = SPIRead8bit();  
  NSS=1;
  return(tmp);
}

/**********************************************************
**Name:     SPIWrite
**Function: SPI Write CMD
**Input:    WrPara -> address & data
**Output:   None
**********************************************************/
void SPIWrite(unsigned int WrPara)                
{                                                       
  unsigned char bitcnt;    
  
  SCK=0;
  NSS=0;
  _nop_();
  WrPara |= 0x8000;                                        //MSB must be "1" for write 
  
  for(bitcnt=16; bitcnt!=0; bitcnt--)
  {
   _nop_();
    SCK=0;
	_nop_();
	_nop_();
	   _nop_();
	  _nop_();
    if(WrPara&0x8000)
      MOSI=1;
    else
      MOSI=0;
	  _nop_();
	  _nop_();
     _nop_();
	  _nop_();
    SCK=1;
	_nop_();
	_nop_();
    WrPara <<= 1;
  }
  SCK=0;
  MOSI=1;
  NSS=1;
}

/**********************************************************
**Name:     SPIBurstRead
**Function: SPI burst read mode
**Input:    adr-----address for read
**          ptr-----data buffer point for read
**          length--how many bytes for read
**Output:   None
**********************************************************/
void SPIBurstRead(unsigned char adr, unsigned char *ptr, unsigned char length)
{
  unsigned char i;
  if(length<=1)                                            //length must more than one
    return;
  else
  {
    SCK=0; 
    NSS=0;
	_nop_();
    SPICmd8bit(adr); 
    for(i=0;i<length;i++)
    ptr[i] = SPIRead8bit();
    NSS=1;  
  }
}

/**********************************************************
**Name:     SPIBurstWrite
**Function: SPI burst write mode
**Input:    adr-----address for write
**          ptr-----data buffer point for write
**          length--how many bytes for write
**Output:   none
**********************************************************/
void BurstWrite(unsigned char adr, unsigned char *ptr, unsigned char length)
{ 
  unsigned char i;

  if(length<=1)                                            //length must more than one
    return;
  else  
  {   
    SCK=0;
    NSS=0;        
    SPICmd8bit(adr|0x80);
    for(i=0;i<length;i++)
    SPICmd8bit(ptr[i]);
    NSS=1;  
  }
}





